@@ -22,7 +22,7 @@ use Image::ExifTool qw/ImageInfo/;
 use English '-no_match_vars';
 use base qw/Exporter/;
 
-our $VERSION   = version->new('0.3.9');
+our $VERSION   = version->new('0.3.10');
 our @EXPORT_OK = qw//;
 
 Readonly my $MARGIN_RATIO             => 0.04;
@@ -561,7 +561,7 @@ SVG::Calendar - Creates calendars in SVG format which can be printed
 
 =head1 VERSION
 
-This documentation refers to SVG::Calendar version 0.3.9.
+This documentation refers to SVG::Calendar version 0.3.10.
 
 =head1 SYNOPSIS
 
@@ -577,8 +577,11 @@ This documentation refers to SVG::Calendar version 0.3.9.
    # print to standard out the calendar for June 2006
    print $svg->output_month( '2006-06' );
 
-   # create a calendar for the year 2007
-   $svg->output_year( );
+   # create a calendar for the year 2007 with filenames
+   #   my-calendar-2015-01.svg
+   #   ...
+   #   my-calendar-2015-12.svg
+   $svg->output_year( '2007', 'my-calendar' );
 
 =head1 DESCRIPTION
 
